searchNodes=[{"doc":"Path Express provides nil-safe list navigation for use with Kernel.get_in/2 plus its own get_in/2 wrapper with some shortcuts.","ref":"PathExpress.html","title":"PathExpress","type":"module"},{"doc":"Returns a function that accesses all the elements in a list. The returned function is typically passed as an accessor to get_in/2 and Kernel.get_in/2. Examples iex&gt; list = [%{name: &quot;john&quot;}, %{name: &quot;mary&quot;}] iex&gt; get_in(list, [PathExpress.all(), :name]) [&quot;john&quot;, &quot;mary&quot;] iex&gt; data = %{items: [%{qty: 1}, %{qty: 2}]} iex&gt; get_in(data, [:items, PathExpress.all(), :qty]) [1, 2] nil or a non-list is traversed by returning empty list: iex&gt; get_in(nil, [PathExpress.all()]) [] iex&gt; get_in(%{}, [PathExpress.all()]) []","ref":"PathExpress.html#all/0","title":"PathExpress.all/0","type":"function"},{"doc":"Returns a function that accesses the element at index (zero based) of a list. The returned function is typically passed as an accessor to get_in/2 and Kernel.get_in/2. Examples # iex&gt; list = [%{name: &quot;john&quot;}, %{name: &quot;mary&quot;}] iex&gt; get_in(list, [PathExpress.at(1), :name]) &quot;mary&quot; iex&gt; get_in(list, [PathExpress.at(-1), :name]) &quot;mary&quot; nil or a non-list is traversed by returning nil: iex&gt; get_in(nil, [PathExpress.at(0)]) nil iex&gt; get_in(%{}, [PathExpress.at(1)]) nil","ref":"PathExpress.html#at/1","title":"PathExpress.at/1","type":"function"},{"doc":"Returns a function that accesses all elements of a list that match the provided predicate. The returned function is typically passed as an accessor to get_in/2 and Kernel.get_in/2. Examples iex&gt; list = [%{name: &quot;john&quot;, salary: 10}, %{name: &quot;francine&quot;, salary: 30}] iex&gt; get_in(list, [PathExpress.filter(&amp;(&amp;1.salary &gt; 20)), :name]) [&quot;francine&quot;] When no match is found, an empty list is returned: iex&gt; list = [%{name: &quot;john&quot;, salary: 10}, %{name: &quot;francine&quot;, salary: 30}] iex&gt; get_in(list, [PathExpress.filter(&amp;(&amp;1.salary &gt;= 50)), :name]) [] nil or a non-list is traversed by returning an empty list, as if no match is found: iex&gt; get_in(nil, [PathExpress.filter(&amp;(&amp;1.salary &gt;= 50)), :name]) [] iex&gt; get_in(%{}, [PathExpress.filter(fn a -&gt; a == 10 end)]) [] An error is raised if the predicate is not a function or is of the incorrect arity: iex&gt; get_in([], [PathExpress.filter(5)]) ** (FunctionClauseError) no function clause matching in PathExpress.filter/1","ref":"PathExpress.html#filter/1","title":"PathExpress.filter/1","type":"function"},{"doc":"Gets a value from a nested structure. Uses a combination of functions from the Access module and PathExpress to traverse the structures in a nil-safe way according to the given keys, unless the key is a function, which is detailed in a later section. Examples iex&gt; users = %{&quot;john&quot; =&gt; %{age: 27}, &quot;meg&quot; =&gt; %{age: 23}} iex&gt; get_in(users, [&quot;john&quot;, :age]) 27 In case any of the keys returns nil, nil will be returned: iex&gt; users = %{&quot;john&quot; =&gt; %{age: 27}, &quot;meg&quot; =&gt; %{age: 23}} iex&gt; get_in(users, [&quot;unknown&quot;, :age]) nil iex&gt; get_in(users, [&quot;unknown&quot;, PathExpress.at(0)]) nil Shortcuts Integers in keys will be treated as PathExpress.at/1 and an empty list will be treated as PathExpress.all/ iex&gt; alias PathExpress, as: PE iex&gt; data = %{&quot;users&quot; =&gt; [%{name: &quot;john&quot;, age: 27}, %{name: &quot;meg&quot;, age: 23}]} iex&gt; PE.get_in(data, [&quot;users&quot;, 0, :name]) &quot;john&quot; iex&gt; PE.get_in(data, [&quot;users&quot;, [], :age]) [27, 23] The examples above are nil-safe: iex&gt; alias PathExpress, as: PE iex&gt; data = %{} iex&gt; PE.get_in(data, [&quot;users&quot;, 0, :name]) nil iex&gt; PE.get_in(data, [&quot;users&quot;, [], :age]) [] Functions as keys See documentation for Kernel.get_in/2","ref":"PathExpress.html#get_in/2","title":"PathExpress.get_in/2","type":"function"}]